@@ -7,7 +7,7 @@
 -- |
 --  Module      :  Internal
 --  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---                 2011, 2012, 2013 Douglas Burke
+--                 2011, 2012, 2013, 2014 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
@@ -79,7 +79,9 @@ import Control.Monad.State (State, get, gets, modify, put)
 
 import Data.List (foldl', groupBy, intersperse, partition)
 import Data.Maybe (isJust)
+#if (!defined(__GLASGOW_HASKELL__)) || (__GLASGOW_HASKELL__ < 710)
 import Data.Monoid (Monoid(..), mconcat)
+#endif
 import Data.Word
 
 import Network.URI (URI)
