@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE FlexibleInstances #-}
 {-# LANGUAGE MultiParamTypeClasses #-}
 {-# LANGUAGE OverloadedStrings #-}
@@ -8,12 +9,12 @@
 -- |
 --  Module      :  Graph
 --  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---                 2011, 2012, 2013 Douglas Burke
+--                 2011, 2012, 2013, 2014, 2015 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
 --  Stability   :  experimental
---  Portability :  FlexibleInstances, MultiParamTypeClasses, OverloadedStrings
+--  Portability :  CPP, FlexibleInstances, MultiParamTypeClasses, OverloadedStrings
 --
 --  This module defines a memory-based RDF graph instance. At present only
 --  RDF 1.0 is explicitly supported; I have not gone through the RDF 1.1
@@ -195,12 +196,15 @@ import Swish.GraphMatch (LabelMap, ScopedLabel(..))
 import Swish.GraphMatch (graphMatch)
 import Swish.QName (QName, getLName)
 
+#if (!defined(__GLASGOW_HASKELL__)) || (__GLASGOW_HASKELL__ < 710)
 import Control.Applicative (Applicative(pure), (<$>), (<*>))
+import Data.Monoid (Monoid(..))
+#endif
+
 import Control.Arrow ((***))
 
 import Network.URI (URI)
 
-import Data.Monoid (Monoid(..))
 import Data.Maybe (mapMaybe)
 import Data.Char (ord, isDigit)
 import Data.Hashable (hashWithSalt)
@@ -209,9 +213,13 @@ import Data.List (intersect, union, foldl')
 import Data.Word (Word32)
 
 import Data.String (IsString(..))
-import Data.Time (UTCTime, Day, ParseTime, parseTime, formatTime)
 
+#if MIN_VERSION_time(1,5,0)
+import Data.Time (UTCTime, Day, ParseTime, parseTimeM, formatTime, defaultTimeLocale)
+#else
+import Data.Time (UTCTime, Day, ParseTime, parseTime, formatTime)
 import System.Locale (defaultTimeLocale)  
+#endif
 
 import Text.Printf
 
@@ -603,7 +611,11 @@ toTimeFormat :: (ParseTime a) => String -> String -> Maybe a
 toTimeFormat fmt inVal =
   let fmtHHMM = fmt ++ "%z"
       fmtZ = fmt ++ "Z"
+#if MIN_VERSION_time(1,5,0)
+      pt f = parseTimeM True defaultTimeLocale f inVal
+#else
       pt f = parseTime defaultTimeLocale f inVal
+#endif
   in case pt fmtHHMM of
     o@(Just _) -> o
     _ -> case pt fmtZ of
@@ -1387,7 +1399,7 @@ grMatchMap g1 g2 =
     graphMatch matchable (getArcs g1) (getArcs g2)
     where
         matchable l1 l2 = mapFormula g1 l1 == mapFormula g2 l2
-	-- hmmm, if we compare the formula, rather then graph,
+        -- hmmm, if we compare the formula, rather then graph,
         -- a lot of tests fail (when the formulae are named by blank
         -- nodes). Presumably because the quality check for Formula forces
         -- the label to be identical, which it needn't be with bnodes
@@ -1572,7 +1584,7 @@ toRDFGraph arcs =
       ns = mapMaybe (fmap getScopeNamespace . getNS) $ S.toList lbls
       nsmap = foldl'
               (\m ins -> let (p,u) = getNamespaceTuple ins
-	                in M.insertWith (flip const) p u m)
+                         in M.insertWith (flip const) p u m)
               emptyNamespaceMap ns
   
   in mempty { namespaces = nsmap, statements = arcs }
@@ -1596,7 +1608,7 @@ updateRDFGraph gr as = gr { statements=as }
 --------------------------------------------------------------------------------
 --
 --  Copyright (c) 2003, Graham Klyne, 2009 Vasili I Galchin,
---    2011, 2012, 2013 Douglas Burke
+--    2011, 2012, 2013, 2014 Douglas Burke
 --  All rights reserved.
 --
 --  This file is part of Swish.
