@@ -1,3 +1,4 @@
+{-# LANGUAGE CPP #-}
 {-# LANGUAGE FlexibleInstances #-}
 {-# LANGUAGE OverloadedStrings #-}
 {-# LANGUAGE TypeSynonymInstances #-}
@@ -7,12 +8,13 @@
 --------------------------------------------------------------------------------
 -- |
 --  Module      :  VarBinding
---  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 2011, 2012 Douglas Burke
+--  Copyright   :  (c) 2003, Graham Klyne, 2009 Vasili I Galchin, 
+--                 2011, 2012, 2014, 2015 Douglas Burke
 --  License     :  GPL V2
 --
 --  Maintainer  :  Douglas Burke
 --  Stability   :  experimental
---  Portability :  FlexibleInstances, OverloadedStrings, TypeSynonymInstances
+--  Portability :  CPP, FlexibleInstances, OverloadedStrings, TypeSynonymInstances
 --
 --  This module defines functions for representing and manipulating query
 --  binding variable sets.  This is the key data that mediates between
@@ -47,18 +49,23 @@ import Swish.RDF.Vocabulary (swishName)
 
 import Swish.Utils.ListHelpers (flist)
 
+#if (!defined(__GLASGOW_HASKELL__)) || (__GLASGOW_HASKELL__ < 710)
 import Control.Applicative ((<$>), (<*>))
+import Data.Monoid (Monoid(..), mconcat)
+#endif
+
 import Control.Monad (mplus)
 
 import Data.Function (on)
 import Data.List (find, intersect, union, (\\), foldl', permutations)
 import Data.Maybe (mapMaybe, fromMaybe, isJust, fromJust, listToMaybe)
-import Data.Monoid (Monoid(..), mconcat)
 import Data.Ord (comparing)
 
 import qualified Data.Map as M
 import qualified Data.Set as S
 
+-- import Prelude
+
 ------------------------------------------------------------
 --  Query variable bindings
 ------------------------------------------------------------
